#
# spec file for package tilix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%define _lto_cflags %{nil}
Name:           tilix
Version:        1.9.6
Release:        2.3
Summary:        A tiling terminal emulator based on GTK+ 3
License:        LGPL-3.0-only AND MPL-2.0
URL:            https://github.com/gnunn1/tilix
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
%if 0%{?sle_version} < 150400 && 0%{?is_opensuse}
Source1:        com.gexperts.Tilix.appdata.xml
%endif
# PATCH-FIX-OPENSUSE gnome-ssh-agent.patch gh#gnunn1/tilix#870
Patch0:         gnome-ssh-agent.patch
%if 0%{?sle_version} < 150400 && 0%{?is_opensuse}
# PATCH-FIX-OPENSUSE 0001-Don-t-generate-appstream-meta-data-on-older-versions.patch -- Provide appdata.xml instead of generating one since we have to old version of appstream in Leap releases
Patch1:         0001-Don-t-generate-appstream-meta-data-on-older-versions.patch
%endif
# PATCH-FIX-UPSTREAM tilix-metainfo-add-developer-id.patch badshah400@gmail.com -- Add a developer id to metainfo to fix failing test; upstream commit
Patch2:         https://github.com/gnunn1/tilix/commit/69fe457b58b58eb6f679bc50ef040d08b40fb65d.patch#/tilix-metainfo-add-developer-id.patch
BuildRequires:  AppStream
BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  ldc
BuildRequires:  ldc-phobos-devel
%if 0%{?sle_version} < 150400 && 0%{?is_opensuse}
BuildRequires:  librsvg-devel
%endif
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  po4a
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gmodule-no-export-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtkd-3) >= 3.8.5
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libunwind)
BuildRequires:  pkgconfig(vte-2.91)
BuildRequires:  pkgconfig(vted-3) >= 3.8.5
BuildRequires:  pkgconfig(x11)
Conflicts:      nautilus-extension-terminix
Conflicts:      terminix

%description
A tiling terminal emulator for Linux using GTK+ 3

%package -n nautilus-extension-tilix
Summary:        Nautilus Extension to Open Tilix in Folders
BuildArch:      noarch
Requires:       python3-nautilus
Supplements:    (nautilus and %{name})

%description -n nautilus-extension-tilix
This is a Nautilus extension that allows you to open tilix in
arbitrary folders.

%lang_package

%prep
%autosetup -p 1

%build
export DFLAGS+=" --allinst"
%meson
%meson_build

# Rename license files so that we can include them in %%license
# Both x11 and icons use LGPL-3.0-only.
cp -a data/icons/LICENSE LICENSE-data-icons
cp -a source/x11/LICENSE LICENSE-source-x11

%install
%meson_install

%if 0%{?sle_version} < 150400 && 0%{?is_opensuse}
mkdir -p %{buildroot}%{_datadir}/metainfo/
install -m 644 %{SOURCE1} %{buildroot}%{_datadir}/metainfo/com.gexperts.Tilix.appdata.xml
%endif

%find_lang %{name} %{?no_lang_C} --with-man

# Some localized man directories are not provided by filesystem package yet
#for locale in uk en_GB hr nb_NO oc pt_PT ro sr tr zh_Hant; do
for locale in uk hr oc ro sr tr zh_Hant; do
  echo "%%dir %{_mandir}/${locale}" >> %{name}.lang
  echo "%%dir %{_mandir}/${locale}/man1" >> %{name}.lang
done

%check
%meson_test

%files
%license LICENSE*
%doc README.md
%{_bindir}/tilix
%{_datadir}/applications/com.gexperts.Tilix.desktop
%{_datadir}/metainfo/com.gexperts.Tilix.appdata.xml
%dir %{_datadir}/tilix
%dir %{_datadir}/tilix/resources
%{_datadir}/tilix/resources/tilix.gresource
%dir %{_datadir}/tilix/schemes
%{_datadir}/tilix/schemes/base16-twilight-dark.json
%{_datadir}/tilix/schemes/linux.json
%{_datadir}/tilix/schemes/material.json
%{_datadir}/tilix/schemes/monokai.json
%{_datadir}/tilix/schemes/orchis.json
%{_datadir}/tilix/schemes/solarized-dark.json
%{_datadir}/tilix/schemes/yaru.json
%{_datadir}/tilix/schemes/solarized-light.json
%{_datadir}/tilix/schemes/tango.json
%dir %{_datadir}/tilix/scripts
%{_datadir}/tilix/scripts/tilix_int.sh
%{_datadir}/icons/hicolor/scalable/apps/com.gexperts.Tilix.svg
%{_datadir}/icons/hicolor/symbolic/apps/com.gexperts.Tilix-symbolic.svg
%{_mandir}/man1/tilix.1%{?ext_man}
%{_datadir}/glib-2.0/schemas/com.gexperts.Tilix.gschema.xml
%{_datadir}/dbus-1/services/com.gexperts.Tilix.service

%files -n nautilus-extension-tilix
%dir %{_datadir}/nautilus-python
%dir %{_datadir}/nautilus-python/extensions
%{_datadir}/nautilus-python/extensions/open-tilix.py

%files lang -f %{name}.lang

%changelog
* Thu Nov 14 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add "--allinst" to DFLAGS env variable to avoid linking errors
  (gh#gnunn1/tilix#2210).
- Add pkgconfig(librsvg-2.0) to BuildRequires to avoid build
  failures on leap 15.x.
- Add tilix-metainfo-add-developer-id.patch: Add a developer id to
  metainfo to fix failing test; upstream commit.
* Thu Nov  9 2023 Emiliano Langella <emiliano.langella@suse.com>
- Update to version 1.9.6
  Features:
  * Add close button to search box
  * Replace variables in custom link commands
  * Follow system color-scheme for default theme-variant
  Bugfixes:
  * nautilus: Don't import a specific version
  * nautilus: Add compatibility with Nautilus 43
  * nautilus: Avoid shell injection in open-tilix plugin
  * Drop manpage country names
  * Replace std.xml with GMarkup-based parser
  * icon: Fix up prompt pictogram alignment
  * Fix GLib critical warnings on startup
  Miscellaneous:
  * Change Gnome to GNOME
  * Replaced icon with more proportional one
  * Update to GtkD 3.10.0
  * ci: Run Ubuntu builds in container as well
  * Change label of "view shortcuts" action
  * Clarify tooltip of "reset to default" button for keyboard shortcuts
- drop patches fixed in release:
  * tilix-nautilus-43-compat.patch
  * b027797.patch
* Tue Apr 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add b027797.patch: Replace std.xml with GMarkup-based parser.
- Build nautilus-extension-tilix as noarch.
* Thu Sep 22 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add tilix-nautilus-43-compat.patch: nautilus: Add compatibility
  with Nautilus 43 [gh#gnunn1/tilix#2115].
* Tue Feb 22 2022 Matthias Eliasson <elimat@opensuse.org>
- Update to version 1.9.5
  Features:
  * Disable advanced paste when there is no linebreak like iTerm2
  * Add environment variable when in quake mode
  * Add possibility to configure always enabled regex
  Bugfixes:
  * More appdata -> metainfo move
  * Add meson target for man page translations
  * Update flatpak manifest
  * meson: drop unused argument for i18n.merge_file()
  * Stop using deprecated Meson features
  * Keep quake window open if focus is restored before timeout has been reached
  * Don't check GtkDragResult (Wayland compatibility)
  * Don't add application/x-rootwindow-drop to dragSourceSet targets
- drop patches fixed in release:
  * 2081.patch
  * tilix-1.9.4-localized-man.patch
- rebase patches:
  * 0001-Don-t-generate-appstream-meta-data-on-older-versions.patch
- change condition since the patches are just required for Leap 15.3.
  Leap 15.4 will not need them
* Mon Feb 21 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add 2081.patch: Fix build using Meson 0.61+.
* Sat Mar  6 2021 Matthias Eliasson <elimat@opensuse.org>
- Fix build for Leap 15.3
  * add build dependency for librsvg-2.0 (was not discovered by pkgconfig)
  * Add patch: 0001-Don-t-generate-appstream-meta-data-on-older-versions.patch
    just used for Leap. Disable appdata.xml generation since we have to old
  version of appstream
  * add uk lang folder for man pages (different from Factory)
  * add com.gexperts.Tilix.appdata.xml file for Leap since we can't generate it
* Tue Feb 23 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Generate and install localized man pages:
  * Add tilix-1.9.4-localized-man.patch
  * Add po4a as build requirement
- Run test in check section.
* Thu Feb 11 2021 Matthias Eliasson <elimat@opensuse.org>
- Update to version 1.9.4
  Features:
  * Actually install Yaru color scheme
  * Give every tab the ${title} (instead of "Default")
  * Add option to strip trailing whitespace on paste (#1904)
  Bugfixes:
  * Fix saving of already saved session
  * Add shortcut to "Unselect all"
  * Many Meson buildsystem fixes
  * Avoid missing the previous command exit code when encoding URLs
  * Resolve some D deprecation messages
  * Mention powerline/fonts in README
  * Avoid calling values() on a shared object
  * Update metainfo data
  * Drop compat code for older D frontend versions
  * Bump minimum VTE version to 0.46
  * Remove deprecated Autotools support
  * Add release notes, NEWS file, automatic metainfo update
  * Update to GtkD 3.9.0
  Translations:
  * This release contains many localization updates
- Simplify by just use ldc as compiler and meson for build on all
  architectures instead of supporting two different build chains
- Drop patches not required for meson builds:
  * dynamic-link.patch
  * fix-ldc-link.patch
- Drop patches fixed upstream:
  * 0001-Avoid-calling-values-on-a-shared-object.patch
  * fix-meson-build.patch
* Fri Jun  5 2020 Matthias Eliasson <elimat@opensuse.org>
- Always apply patch 0001-Avoid-calling-values-on-a-shared-object.patch
  so we fix builds for all openSUSE distributions
* Fri Jun  5 2020 Matthias Eliasson <elimat@opensuse.org>
- Refresh Patch (fix-meson-build.patch) with some minor updates from upstream
- Package man file
- Add patch 0001-Avoid-calling-values-on-a-shared-object.patch to make it build on newer ldc
* Wed Jun  3 2020 Max Lin <mlin@suse.com>
- Use python3-nautilus for Leap 15.2 since python2-nautilus has been dropped
* Sat Nov 30 2019 Matthias Eliasson <elimat@opensuse.org>
- Use python3-nautilus dependency for Tumbleweed since python2 support have
  been droped. Still keep python2-nautilus for older Leap releases. (boo#1158039)
* Thu May 30 2019 Matthias Eliasson <elimat@opensuse.org>
- Major changes in build
  * Add patch (fix-meson-build.patch) to fix meson and start to use it for Tumbleweed
    (upstream is heading this way)
  * Switch to ldc as d-compiler for Tumbleweed. ldc have better architectures support
    than dmd and its easier just to support one.
  * Start to use gtkd in repos for Tumbleweed so we don't need to staticly link it to tilix
  * Make tilix build on Leap 42.3
* Tue May 28 2019 Matthias Eliasson <elimat@opensuse.org>
- Update to version 1.9.3
  * This issue fixes a problem with the session sidebar getting out of sync
    after having deleted a session.
* Sun Mar 17 2019 Matthias Eliasson <elimat@opensuse.org>
- Update to version 1.9.0
  * This is a very minor release that fixes the app menu for Gnome 3.32,
    updates the icon and adds preferences to the gnome-shell menu item
  similar to Gnome Terminal.
- Add comment in spec for for patch: gnome-ssh-agent.patch
- Refresh patch: gnome-ssh-agent.patch
* Mon Jan 14 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Refresh patch due to previous updates:
  * fix-ldc-link.patch
* Mon Jan  7 2019 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to version 1.8.9
  * A very small release to update localizations and address an issue
    in GtkD where the version number was not updated correctly.
* Sat Jan  5 2019 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to version 1.8.7
  * Added ability to assign shortcuts to profiles
  * Included app menu options in hamburger menu in preparation to conform to GNOME HIG changes
  * Mitigated memory leak with sidebar
  * Fixed minor color issues with Solarized schemes
  * Fixed issue with decoding strings that didn't need it (thanks to Chris Billington)
  * Fixed issue with blurry text when background image was set on scaled display
  * Fixed issue with scaling badge when using font scaling
  * Added ability to include statuses (readonly, silence and input-sync enabled) to terminal title
  * Updated to use GTKD 3.84
  * Updated app data thanks to Bilal Elmoussaoui
  * Fixed issue with drag window remaining visible thanks to Jocelyn Turcotte
  * Tilix icon updated to reflect new GNOME design thanks to Sergey Bugaev
  * Fixed problem with unsafe paste dialog when command has excessive length thanks to Bilal Elmoussaoui
- Ran spec-cleaner
* Fri Dec  7 2018 Richard Brown <rbrown@suse.com>
- Require libvted to solve "vte config is invalid" errors
* Thu Nov 22 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable build with ldc where dmd is not supported
- Add patch to fix build with ldc:
  * fix-ldc-link.patch
* Wed Sep 26 2018 Matthias Eliasson <matthias.eliasson@gmail.com>
- Revert to use dmd d-compiler for Tumbleweed to make it build again.
* Tue Aug 28 2018 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to 1.8.5
  * This release is just to fix a bug that prevents the tilix preferences from
  working on GTK releases earlier then 3.22, no other changes have been made.
* Sun Aug 19 2018 matthias.eliasson@gmail.com
- Update to 1.8.3
  * Added the ability to customize the badge font and size
  * Fixed an issue with loading URLs with a hash character
  * Fixed an issue where tilix could get stuck in mazimized mode when a
    background terminal closes behind the scenes
  * Added an indicator on the tab to show when new output is detected, only works
    with VTE alternate-screen patch
  * Can now use Tab key when customizing shortcuts
  * Re-worked notifications so each terminal has it's own notification rather then one
    global one for tilix
  * Updated to use GtkD 3.8.3
  * Added experimental support for process monitoring where the currently running
    process can be used in the terminal title. Requires enabling a setting in Dconf
  prefs, may cause segfaults
  * Various other bug fixes
* Sat Jul 28 2018 matthias.eliasson@gmail.com
- Start using ldc d-compiler with autotools for Tumbleweed now it is in the repo.
- Start using gtkd dependency from repo instead of included gtkd archive for Tumbleweed.
- Add licenses for x11 and icons included in tilix.
* Sat May 26 2018 matthias.eliasson@gmail.com
- Update to 1.8.1
  * Added support for toggling a margin line (https://gnunn1.github.io/tilix-web/manual/margin)
  * Added new shortcut for auto-oriented splitting, thanks to @henvo
  * When tabs are on the left or right they are now displayed vertically to fix space issues (gh#gnunn1/tilix#1395)
  * Fixed a memory leak when closing sessions (gh#gnunn1/tilix#1409)
  * Improved color matching logic for matching themes (gh#gnunn1/tilix#1400)
- Drop patch: fix-i586-build.patch
  * This is fixed upstream
- Drop patch: fix-build-with-latest-dmd.patch
  * This is fixed upstream
* Sun May 13 2018 matthias.eliasson@gmail.com
- Added patch: fix-i586-build.patch
  * This to resolve build issues for i586 Tumbleweed.
- Added patch: fix-build-with-latest-dmd.patch
  * Some changes to dmd-2.080.0 made the builds fail.
    This patch correct it.
* Tue May  1 2018 matthias.eliasson@gmail.com
- Update to 1.7.9
  * Badges for all! As of VTE 0.52 a Tilix specific VTE patch for
    badge support is no longer required
  * Support for new VTE 0.52 features (gh#gnunn1/tilix#1233)
  * New shortcuts to quickly cycle through previous command prompts.
    Requires VTE be compiled with Tilix alternate screen patch
    (gh#gnunn1/tilix#1369)
  * Profiles in preferences has been re-worked so dialog uses less
    vertical space
  * New GtkD 3.8.2 used which fixes a segmentation fault when
    casting objects from a null object
  * Unsafe paste dialog uses a scrollwindow now when more then 6
    lines of text (gh#gnunn1/tilix#1386)
  * A new token ${activeTerminalTitle} has been added to provide
    more flexibility for session titles
  * Triggers and custom hyperlinks now support using the tilix
    tokens (gh#gnunn1/tilix#1316)
  * Custom hyperlinks are loaded before the default hyperlinks so
    users can override default behavior
* Sat Apr 14 2018 matthias.eliasson@gmail.com
- Add patch: dynamic-link.patch: link against shared library
- Use %%license macro
* Wed Mar 14 2018 michele.bologna@suse.com
- Update to 1.7.7
- Added patch: gnome-ssh-agent.patch
  * Solves the problem with GNOME keyring and ssh-agent:
  https://github.com/gnunn1/tilix/issues/870#issuecomment-291849303
* Sat Jan 13 2018 matthias.eliasson@gmail.com
- Update to 1.7.5
  * Fixed segfault with input synchronization occurring after a period of time (gh#gnunn1/tilix#1228)
  * Passwords and bookmarks now respect input synchronization (gh#gnunn1/tilix#1236)
  * Fix problem with Copy as HTML not checking VTE version (gh#gnunn1/tilix#1235)
- Update copyright year
- Remove patch: tilix-fix-1.7.3-build-on-32bits.patch (fixed upstream)
* Mon Jan  1 2018 matthias.eliasson@gmail.com
- Update to 1.7.3
  * This release improves the stability of Tilix plus fixes a few minor issues.
    The only new feature is being able to copy terminal output as HTML.
- Update version of build dependency gtkd to 3.7.3
- Remove patch: tilix-fix-1.7.1-build-on-32bits.patch (fixed upstream)
- Add patch: tilix-fix-1.7.3-build-on-32bits.patch
- Should now build on i586 arch
* Thu Dec 21 2017 mimi.vx@gmail.com
- remove unnneded post/postun sections
* Fri Dec  1 2017 matthias.eliasson@gmail.com
- Fix so tilix runs correctly
* Wed Nov 22 2017 matthias.eliasson@gmail.com
- Add tilix-fix-1.7.1-build-on-32bits.patch to fix builds on i586
* Wed Nov 22 2017 matthias.eliasson@gmail.com
- Update to version 1.7.1
  * This release fixes a single issue with 1.7.0 where the default for the overlay scrollbar was set to false.
- Run spec-cleaner
- Remove buildignore for gcc-PIE not needed anymore.
- Bump version of build dependency gtkd to 3.6.6
* Sun Jul 23 2017 matthias.eliasson@gmail.com
- Remove _service and add the specific source files
* Sat Jul 22 2017 matthias.eliasson@gmail.com
- bump version to 1.6.4
  * Dim option now dims the fonts and does not alter the background. The dim color option has been removed
  * Added option to disable saving/restoring window state between invocations
  * Added option to disable overlay scrollbar in favor of separate scrollbar widget
  * Fixed problem with selecting non-existent bookmark causing a crash
  * Enabled customizing keyboard shortcut for toggling local input synchronization
  * Added abilitiy to specify window style from command line
  * Added menu option to open CWD in file browser (i.e. Nautilus, etc)
  * Fixed issue where opening a custom link could only be done once
- bump version of build dependency gtkd to 3.6.5
- spec-cleaner
- add buildignore gcc-PIE to make this build for now are waiting for some fixes upstream:
  https://github.com/dlang/phobos/pull/5586
* Fri Apr 28 2017 matthias.eliasson@gmail.com
- bump version to 1.5.6
  * Added the ability to specify custom hyperlinks and triggers globally as well as in profiles
  * Triggers now support executing a process and passing the output of the process to the terminal
  * Fixed issue for CentOS and RHEL 7.x where it would not run on GTK 3.14
  * Sidebar now ensures active session is shown when opening
  * Removed the option to disable animation in quake mode, was causing other issues
  * Fixed New Window options Split Down and Split Right
  * Fixed various focus issues
  * Added option to bookmarks to automatically insert line feed
  * Fixed Wayland issue where dragging and dropping a terminal on the desktop did not create a new window like it does in X11
* Mon Mar 27 2017 vinadoros@outlook.com
- Upstream rename from terminix to tilix
- bump version to 1.5.4
  * Detaching terminal in Wayland by dropping it on desktop now works identically to X11
  * Fixed issue with outdated LDC libraries on Fedora, this should allow COPR to work again
  * Fixed issue with close dialog and long process names resulting in excessively wide dialog box
  * Removed animation hint feature from quake mode as it was causing focus issues
  * Fixed crash when loading multiple sessions from file
* Wed Mar  8 2017 matthias.eliasson@gmail.com
- bump version to 1.5.2
  * Removed Timeout from terminal to fix segfault with visual bell
  * Fixed Nautilus plugin where it was crashing Nautilus for some users thanks to @bil-elmoussaoui
  * Variables used in application title now resolve correctly.
  * Fix version number
* Tue Feb 21 2017 kkaempf@suse.com
- bump version to 1.5.0
  * Added initial support for bookmarks
  * Re-worked terminal menu to include bookmark and password options,
    some lesser used options moved to a sub-menu
  * Added a new feature to raise a notification if activity is
    detected after a specified period of silence
  * Search button now toggles depending if focused terminal has
    search open
  * Improved performance when using background images
  * Added new Window Appearance preference
  * Improved title editors in preferences to show available variables
  * Re-worked -e option to fix some bugs, should work better across
    more permutations
  * Many bug fixes
- update GtkD to 3.5.1
* Mon Jan 16 2017 matthias.eliasson@gmail.com
- bump version to 1.4.2
- add man page to files section
* Mon Dec 26 2016 matthias.eliasson@gmail.com
- bump version 1.4.0
- remove desktop.patch since this have been fixed upstream.
- Modified %%files section to include all files for package
* Fri May  6 2016 mailaender@opensuse.org
- initial packaging of version 0.59.0
